@@ -11,6 +11,7 @@
 #' @param A A matrix (n x [p x k]) or 3D array (p x k x n) containing GPA-aligned coordinates for a set of specimens
 #' @param labels A logical value indicating whether taxa labels (tips and ancestors) should be included
 #' @param ancStates A logical value indicating whether ancestral state values should be returned
+#' @param plot.param A list of plotting parameters for the tips (t.bg, t.pch, t.cex), nodes (n.bg, n.pch, n.cex), branches (l.col, lwd), and taxa labels (txt.cex, txt.adj, txt.col)
 #' @export
 #' @keywords visualization
 #' @author Dean Adams & Emma Sherratt
@@ -24,7 +25,10 @@
 #' Y.gpa<-gpagen(plethspecies$land)    #GPA-alignment    
 #'
 #' plotGMPhyloMorphoSpace(plethspecies$phy,Y.gpa$coords)
-plotGMPhyloMorphoSpace<-function(phy,A,labels=TRUE,ancStates=TRUE){
+#' plotGMPhyloMorphoSpace(plethspecies$phy,Y.gpa$coords, 
+#'                  plot.param=list(t.bg="blue",txt.col="red",n.cex=1))
+plotGMPhyloMorphoSpace<-function(phy,A,labels=TRUE,ancStates=TRUE, 
+                                 plot.param = list()){
   if(any(is.na(A))==T){
     stop("Data matrix contains missing values. Estimate these first (see 'estimate.missing').")  }
   if (length(dim(A))==3){ 
@@ -46,6 +50,13 @@ plotGMPhyloMorphoSpace<-function(phy,A,labels=TRUE,ancStates=TRUE){
     stop("Data matrix missing some taxa present on the tree.")
   if(length(match(phy$tip.label,rownames(x)))!=N) 
     stop("Tree missing some taxa in the data matrix.")
+  p.p <- plot.param
+    if(is.null(p.p$t.bg)) p.p$t.bg="black" ; if(is.null(p.p$t.pch)) p.p$t.pch=21
+    if(is.null(p.p$t.cex)) p.p$t.cex=2 ; if(is.null(p.p$n.bg)) p.p$n.bg="white"
+    if(is.null(p.p$n.pch)) p.p$n.pch=21 ; if(is.null(p.p$n.cex)) p.p$n.cex=1.25
+    if(is.null(p.p$l.col)) p.p$l.col="black" ; if(is.null(p.p$lwd)) p.p$lwd=3
+    if(is.null(p.p$txt.adj)) p.p$txt.adj=c(-.1,-.1) ; if(is.null(p.p$txt.col)) p.p$txt.col="black"
+    if(is.null(p.p$txt.cex)) p.p$txt.cex=1
   x<-x[phy$tip.label, ]  
   names<-row.names(x)
   anc.states<-NULL
@@ -67,11 +78,11 @@ plotGMPhyloMorphoSpace<-function(phy,A,labels=TRUE,ancStates=TRUE){
   if(labels==FALSE) {
     plot(pcdata,type="n",asp=1) }
   for (i in 1:nrow(phy$edge)){
-    lines(pcdata[(phy$edge[i,]),1],pcdata[(phy$edge[i,]),2],type="l",pch=21,col="black",lwd=3)
+    lines(pcdata[(phy$edge[i,]),1],pcdata[(phy$edge[i,]),2],type="l",col=p.p$l.col,lwd=p.p$lwd)
   }
-  points(pcdata[1:N,],pch=21,bg="black",cex=2)
-  points(pcdata[(N+1):nrow(pcdata),],pch=21,bg="white",cex=1.25)
+  points(pcdata[1:N,], pch=p.p$t.pch, bg=p.p$t.bg, cex=p.p$t.cex)
+  points(pcdata[(N+1):nrow(pcdata),], pch=p.p$n.pch, bg=p.p$n.bg, cex=p.p$n.cex)
   if(labels==TRUE){
-    text(pcdata[,1],pcdata[,2],rownames(pcdata),cex=0.75,adj=c(-.1,-.1))}
+    text(pcdata[,1],pcdata[,2],rownames(pcdata),col=p.p$txt.col,cex=p.p$txt.cex,adj=p.p$txt.adj)}
   if(ancStates==TRUE){ return(anc.states)  }
 }
\ No newline at end of file
