@@ -8,8 +8,8 @@
 #' high-dimensional datasets. The approach is derived from the statistical equivalency between parametric methods 
 #' utilizing covariance matrices and methods based on distance matrices (Adams 2014). Data input is specified by 
 #' a formula (e.g., y~X), where 'y' specifies the response variables (shape data), and 'X' contains one or more 
-#' independent variables (discrete or continuous). The response matrix 'y' must be in the form of a two-dimensional data 
-#'   matrix of dimension (n x [p x k]), rather than a 3D array.  It is assumed that the landmarks have previously 
+#' independent variables (discrete or continuous). The response matrix 'y' can be either in the form of a two-dimensional data 
+#'   matrix of dimension (n x [p x k]), or a 3D array (p x n x k).  It is assumed that the landmarks have previously 
 #'   been aligned using Generalized Procrustes Analysis (GPA) [e.g., with \code{\link{gpagen}}].
 #'   The user must also specify a phylogeny describing the evolutionary relationships among species (of class phylo).
 #'   Note that the specimen labels for both x and y must match the labels on the tips of the phylogeny.
@@ -53,21 +53,20 @@
 #' ### Example of D-PGLS for high-dimensional data 
 #' data(plethspecies)
 #' Y.gpa<-gpagen(plethspecies$land)    #GPA-alignment
-#' procD.pgls(two.d.array(Y.gpa$coords)~Y.gpa$Csize,plethspecies$phy,iter=49)
+#' procD.pgls(Y.gpa$coords ~ Y.gpa$Csize,plethspecies$phy,iter=49)
 #'
 #' ### Example of D-PGLS for high-dimensional data, using RRPP
-#' procD.pgls(two.d.array(Y.gpa$coords)~Y.gpa$Csize,plethspecies$phy,iter=49,RRPP=TRUE)
+#' procD.pgls(Y.gpa$coords ~ Y.gpa$Csize,plethspecies$phy,iter=49,RRPP=TRUE)
 procD.pgls<-function(f1, phy, iter=999, int.first = FALSE, RRPP=FALSE, verbose=FALSE){
   data=NULL
   form.in <- formula(f1)
+  Y <- eval(form.in[[2]], parent.frame())
+  if(length(dim(Y)) == 3)  Y <- two.d.array(Y) else Y <- as.matrix(Y)
+  form.in <- as.formula(paste(c("Y",form.in[[3]]),collapse="~"))
   if(int.first == TRUE) ko = TRUE else ko = FALSE
   Terms <- terms(form.in, keep.order = ko)
   k <- length(attr(Terms, "term.labels"))
   mf <- model.frame(form.in)
-  Y <- as.matrix(mf[1])
-  if (length(dim(Y)) != 2) {
-    stop("Response matrix (shape) not a 2D array. Use 'two.d.array' first.")
-  }  
   if (any(is.na(Y)) == T) {
     stop("Response data matrix (shape) contains missing values. Estimate these first (see 'estimate.missing').")
   }
@@ -88,8 +87,8 @@ procD.pgls<-function(f1, phy, iter=999, int.first = FALSE, RRPP=FALSE, verbose=F
   }
   eigC.vect = eigC$vectors[,1:(length(lambda))]
   Pcor <- solve(eigC.vect%*% diag(sqrt(lambda)) %*% t(eigC.vect)) 
-  PY <- Pcor%*%Y   #Garland & Ives 2000 transformation
-  Xs = mod.mats(mf)
+  PY <- Pcor%*%Y   
+  Xs = mod.mats(form.in, mf)
   
   anova.parts.obs <- anova.pgls.parts(form.in, X=NULL, Pcor, Yalt = "observed", keep.order=ko)
   anova.tab <-anova.parts.obs$table  
